#ifndef RING_BUFFER_H
#define RING_BUFFER_H

#include <stdbool.h>
#include <stdint.h>


#ifdef __AVR_ATmega328P__
#define RING_BUFFER_CAPACITY (512)
#else
#define RING_BUFFER_CAPACITY (4)
#endif

typedef struct ring_buffer_t_ 
{
  uint8_t data_length;
  uint8_t read_pointer;
  uint8_t write_pointer;
  uint8_t storage[RING_BUFFER_CAPACITY];
} 
ring_buffer_t;


void ring_buffer_init(ring_buffer_t *buffer);
void ring_buffer_clear(ring_buffer_t *buffer);

bool ring_buffer_is_empty(ring_buffer_t const *buffer);
bool ring_buffer_is_full(ring_buffer_t const *buffer);

void ring_buffer_push(ring_buffer_t *buffer, uint8_t byte);
uint8_t ring_buffer_pop(ring_buffer_t *buffer);


#endif // RING_BUFFER_H
